from marshmallow import Schema, fields, post_load, validates, ValidationError
from flask import request
import re
from app.doctor.models import Doctor

class DoctorSchema(Schema):
    doctor_name = fields.String(required=True)
    site_id = fields.Integer(required=True)
    logo_id = fields.Integer(required=False)  
    gender = fields.String(required=True)
    dob = fields.Date(allow_none=True)
    specialization = fields.String(required=False)
    email = fields.String(required=False)
    device_name = fields.String(required=False)
    device_id = fields.String(required=False)

    @validates("doctor_name")
    def validate_doctor_name(self, value):
        if not value.strip():
            raise ValidationError("The Doctor Name field is required.")

    @validates("email")
    def validate_email(self, value):
        if not value.strip():
            raise ValidationError("The Email field is required.")
        if not re.match("[^@]+@[^@]+\.[^@]+", value):
            raise ValidationError("Invalid email format")
        if request.method == 'POST':
            existing_doctor = Doctor.query.filter_by(email=value).first()
            if existing_doctor:
                raise ValidationError("Email already exists for another doctor")
        
    @post_load
    def make_doctor(self, data, **kwargs):
        return data

doctor_schema = DoctorSchema()
doctors_schema = DoctorSchema(many=True)
